# Miscellaneous

Note: all tools in this folder are *miscellaneous* and do not interact in any way with the rest of AeroSandbox. **If you are trying to learn AeroSandbox, you should ignore this folder and move on.**

Some of them may even use libraries which are not required as part of a base install of AeroSandbox, so many of these scripts won't work without extra hacking on users' ends.

Think of this as a "Gists" folder - random snippets and scripts from scientific computing work go here.